@@ -3,6 +3,7 @@
 #'
 #' @param surveyID String. Unique survey ID for the distribution data you want to download.
 #'
+#' @template retry-advice
 #' @export
 #'
 #' @examples
@@ -66,11 +67,10 @@ fetch_distributions <- function(surveyID){
                       recipients_sampleId = purrr::map_chr(recipients, "sampleId", .default = NA_character_),
                       message_libraryId = purrr::map_chr(message, "libraryId", .default = NA_character_),
                       message_messageId = purrr::map_chr(message, "messageId", .default = NA_character_),
-                      message_messageText = purrr::map_chr(message, "messageText", .default = NA_character_),
+                      message_messageType = purrr::map_chr(message, "messageType", .default = NA_character_),
                       surveyLink_surveyId = purrr::map_chr(surveyLink, "surveyId", .default = NA_character_),
                       surveyLink_expirationDate = purrr::map_chr(surveyLink, "expirationDate", .default = NA_character_),
                       surveyLink_linkType = purrr::map_chr(surveyLink, "linkType", .default = NA_character_),
-                      embeddedData = purrr::map_chr(elements, "embeddedData", .default = NA_character_),
                       stats_sent = purrr::map_int(stats, "sent", .default = NA_integer_),
                       stats_failed = purrr::map_int(stats, "failed", .default = NA_integer_),
                       stats_started = purrr::map_int(stats, "started", .default = NA_integer_),
