@@ -8,7 +8,9 @@ test_that("metadata() should throw an error if passing invalid options to input"
 
 })
 
-test_that("metadata() should throw warning if input questions are not a vector", {
+
+
+test_that("metadata() should throw error if input questions are not a vector", {
 
   expect_error(
     metadata("mockId1", questions = "I am not a vector")
@@ -30,8 +32,20 @@ test_that("metadata() should return metadata + questions + responsecounts", {
 
 })
 
+test_that("metadata() returns flow if specified in new way (char vec)", {
 
-test_that("metadata() returns flow if specified", {
+  vcr::use_cassette("metadata_flow", {
+    x <- metadata("SV_3gbwq8aJgqPwQDP", get = "flow")
+  })
+
+  expect_type(x, c("list"))
+  expect_named(x, "flow")
+  expect_equal(length(x$flow), 4)
+
+})
+
+
+test_that("metadata() ADDS flow if specified in old way (logical list)", {
 
   vcr::use_cassette("metadata_flow", {
     x <- metadata("SV_3gbwq8aJgqPwQDP", get = list(flow = TRUE))
